@@ -80,6 +80,7 @@ def test_algorithm_unhashed(topology_with_tls, encryption):
     And check unhashed#user#password attribute for encryption.
 
     :id: b7a37bf8-4b2e-4dbd-9891-70117d67558c
+    :parametrized: yes
     :setup: Replication with two masters and SSL configured.
     :steps: 1. Enable changelog encrytion on master1 (try AES and 3DES).
             2. Add a user to master1/master2
@@ -104,6 +105,8 @@ def test_algorithm_unhashed(topology_with_tls, encryption):
 
     m1 = topology_with_tls.ms['master1']
     m2 = topology_with_tls.ms['master2']
+    m1.config.set('nsslapd-unhashed-pw-switch', 'on')
+    m2.config.set('nsslapd-unhashed-pw-switch', 'on')
     test_passw = 'm2Test199'
 
     _enable_changelog_encryption(m1, encryption)
