@@ -280,15 +280,14 @@ struct berval *NSDS90StartReplicationRequest_new(const char *protocol_oid,
 int multimaster_extop_NSDS50ReplicationEntry(Slapi_PBlock *pb);
 
 /* From repl_globals.c */
-extern char *attr_changenumber;
-extern char *attr_targetdn;
-extern char *attr_changetype;
-extern char *attr_newrdn;
-extern char *attr_deleteoldrdn;
-extern char *attr_changes;
-extern char *attr_newsuperior;
-extern char *attr_changetime;
-extern char *attr_dataversion;
+extern char *repl_changenumber;
+extern char *repl_targetdn;
+extern char *repl_changetype;
+extern char *repl_newrdn;
+extern char *repl_deleteoldrdn;
+extern char *repl_changes;
+extern char *repl_newsuperior;
+extern char *repl_changetime;
 extern char *attr_csn;
 extern char *changetype_add;
 extern char *changetype_delete;
@@ -777,7 +776,7 @@ void replica_disable_replication(Replica *r);
 int replica_start_agreement(Replica *r, Repl_Agmt *ra);
 int windows_replica_start_agreement(Replica *r, Repl_Agmt *ra);
 
-CSN *replica_generate_next_csn(Slapi_PBlock *pb, const CSN *basecsn);
+int32_t replica_generate_next_csn(Slapi_PBlock *pb, const CSN *basecsn, CSN **opcsn);
 int replica_get_attr(Slapi_PBlock *pb, const char *type, void *value);
 
 /* mapping tree extensions manipulation */
@@ -812,6 +811,11 @@ typedef struct _cleanruv_purge_data
     char *replGen;
 } cleanruv_purge_data;
 
+typedef struct _csngen_test_data
+{
+    Slapi_Task *task;
+} csngen_test_data;
+
 /* In repl5_replica_config.c */
 int replica_config_init(void);
 void replica_config_destroy(void);
