@@ -471,7 +471,7 @@ slapi_escape_filter_value(char *filter_str, int len)
 void
 replace_char(char *str, char c, char c2)
 {
-    for (size_t i = 0; (str != NULL) && (str[i] != NULL); i++) {
+    for (size_t i = 0; (str != NULL) && (str[i] != '\0'); i++) {
         if (c == str[i]) {
             str[i] = c2;
         }
