@@ -60,7 +60,7 @@ const staticStates = {
 };
 
 export class DSInstance extends React.Component {
-    componentWillMount() {
+    componentDidMount() {
         this.loadInstanceList();
         this.updateProgress(25);
     }
@@ -332,6 +332,11 @@ export class DSInstance extends React.Component {
     }
 
     handleServerIdChange(e) {
+        this.setState({
+            pageLoadingState: { state: "loading", jsx: "" },
+            progressValue: 25,
+            serverId: e.target.value
+        });
         this.loadInstanceList(e.target.value);
     }
 
@@ -625,6 +630,7 @@ export class DSInstance extends React.Component {
                                                 addNotification={this.addNotification}
                                                 serverId={this.state.serverId}
                                                 wasActiveList={this.state.wasActiveList}
+                                                key={this.state.serverId}
                                             />
                                         </TabPane>
                                         <TabPane eventKey={2}>
@@ -632,6 +638,7 @@ export class DSInstance extends React.Component {
                                                 addNotification={this.addNotification}
                                                 serverId={this.state.serverId}
                                                 wasActiveList={this.state.wasActiveList}
+                                                key={this.state.serverId}
                                             />
                                         </TabPane>
                                         <TabPane eventKey={3}>
@@ -639,6 +646,7 @@ export class DSInstance extends React.Component {
                                                 addNotification={this.addNotification}
                                                 serverId={this.state.serverId}
                                                 wasActiveList={this.state.wasActiveList}
+                                                key={this.state.serverId}
                                             />
                                         </TabPane>
                                         <TabPane eventKey={4}>
@@ -646,6 +654,7 @@ export class DSInstance extends React.Component {
                                                 addNotification={this.addNotification}
                                                 serverId={this.state.serverId}
                                                 wasActiveList={this.state.wasActiveList}
+                                                key={this.state.serverId}
                                             />
                                         </TabPane>
                                         <TabPane eventKey={5}>
@@ -653,6 +662,7 @@ export class DSInstance extends React.Component {
                                                 addNotification={this.addNotification}
                                                 serverId={this.state.serverId}
                                                 wasActiveList={this.state.wasActiveList}
+                                                key={this.state.serverId}
                                             />
                                         </TabPane>
                                         <TabPane eventKey={6}>
@@ -660,6 +670,7 @@ export class DSInstance extends React.Component {
                                                 addNotification={this.addNotification}
                                                 serverId={this.state.serverId}
                                                 wasActiveList={this.state.wasActiveList}
+                                                key={this.state.serverId}
                                             />
                                         </TabPane>
                                     </TabContent>
@@ -782,10 +793,14 @@ class CreateInstanceModal extends React.Component {
             return;
         }
         newServerId = newServerId.replace(/^slapd-/i, ""); // strip "slapd-"
-        if (newServerId.length > 128) {
+        if (newServerId === "admin") {
+            addNotification("warning", "Instance Name 'admin' is reserved, please choose a different name");
+            return;
+        }
+        if (newServerId.length > 80) {
             addNotification(
                 "warning",
-                "Instance name is too long, it must not exceed 128 characters"
+                "Instance name is too long, it must not exceed 80 characters"
             );
             return;
         }
