@@ -69,17 +69,15 @@ export class ServerSASL extends React.Component {
         this.deleteMapping = this.deleteMapping.bind(this);
     }
 
-    componentWillMount() {
+    componentDidMount() {
         // Loading config
         if (!this.state.loaded) {
             this.loadConfig();
+        } else {
+            this.props.enableTree();
         }
     }
 
-    componentDidMount() {
-        this.props.enableTree();
-    }
-
     handleTestRegex() {
         let test_string = this.state.saslTestText;
         let regex = this.state.saslMapRegex;
@@ -345,7 +343,7 @@ export class ServerSASL extends React.Component {
                         loaded: true,
                         tableLoading: false,
                         configLoading: false,
-                    });
+                    }, this.props.enableTree);
                 });
     }
 
