@@ -1,15 +1,12 @@
 # --- BEGIN COPYRIGHT BLOCK ---
-# Copyright (C) 2015 Red Hat, Inc.
+# Copyright (C) 2020 Red Hat, Inc.
 # All rights reserved.
 #
 # License: GPL (version 3 or any later version).
 # See LICENSE for details.
 # --- END COPYRIGHT BLOCK ---
 
-import ldap
-import sys
-from lib389._constants import *
-from lib389.properties import *
+
 from lib389._mapped_object import DSLdapObjects, DSLdapObject
 
 
@@ -47,4 +44,4 @@ class EncryptedAttrs(DSLdapObjects):
         self._objectclasses = ['nsAttributeEncryption']
         self._filterattrs = ['cn']
         self._childobject = EncryptedAttr
-        self._basedn = basedn
\ No newline at end of file
+        self._basedn = basedn
